Subrosa
=======

.. image:: https://travis-ci.org/DasIch/subrosa.svg?branch=master
   :target: https://travis-ci.org/DasIch/subrosa
   :alt: Travis CI Status

.. image:: https://codecov.io/gh/DasIch/subrosa/coverage.svg
   :target: https://codecov.io/gh/DasIch/subrosa
   :alt: Codecov Status


.. image:: https://readthedocs.org/projects/hybrid-attributes/badge/?version=latest
   :target: http://hybrid-attributes.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation


Subrosa is a Python implementation of `Shamir's Secret Sharing`__. An algorithm
for sharing a secret with a group of people without letting any individual of
the group know the secret.

Subrosa is BSD license and available for Python 3.4 and later.


__ https://en.wikipedia.org/wiki/Shamir%27s_Secret_Sharing
